@@ -1,41 +1,34 @@
 #[cfg(feature = "async")]
 mod async_example {
     use futures::stream::TryStreamExt;
+    use once_cell::sync::Lazy;
     use std::{
-        fs::File,
-        io::{self, BufWriter},
-        path::PathBuf,
+        fs::{self, File},
+        io::{self, prelude::*, BufWriter},
+        path::{Path, PathBuf},
     };
-    use tfrecord::{Error, Feature, RecordStreamInit};
+    use tfrecord::{Error, ExampleStream, FeatureKind};
 
-    lazy_static::lazy_static! {
-        pub static ref INPUT_TFRECORD_PATH: PathBuf = {
-            let url = "https://storage.googleapis.com/download.tensorflow.org/data/fsns-20160927/testdata/fsns-00000-of-00001";
-            let file_name = "input.tfrecord";
-
-            let data_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("test_data");
-            std::fs::create_dir_all(&data_dir).unwrap();
-
-            let out_path = data_dir.join(file_name);
-            io::copy(
-                &mut ureq::get(url).call().unwrap().into_reader(),
-                &mut BufWriter::new(File::create(&out_path).unwrap()),
-            ).unwrap();
-
-            out_path
-        };
-        pub static ref DATA_DIR: PathBuf = {
-            let data_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("test_data");
-            std::fs::create_dir_all(&data_dir).unwrap();
-            data_dir
-        };
-    }
+    static INPUT_TFRECORD_PATH: Lazy<PathBuf> = Lazy::new(|| {
+        (move || {
+            let url = include_str!("../tests/tfrecord_link.txt");
+            let path = DATA_DIR.join("input.tfrecord");
+            let mut writer = BufWriter::new(File::create(&path)?);
+            io::copy(&mut ureq::get(url).call()?.into_reader(), &mut writer)?;
+            writer.flush()?;
+            anyhow::Ok(path)
+        })()
+        .unwrap()
+    });
+    static DATA_DIR: Lazy<&Path> = Lazy::new(|| {
+        let path = Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/test_data"));
+        fs::create_dir_all(path).unwrap();
+        path
+    });
 
     pub async fn _main() -> Result<(), Error> {
         // use init pattern to construct the tfrecord stream
-        let stream = RecordStreamInit::default()
-            .examples_open(&*INPUT_TFRECORD_PATH)
-            .await?;
+        let stream = ExampleStream::open(&*INPUT_TFRECORD_PATH, Default::default()).await?;
 
         // print header
         println!("example_no\tfeature_no\tname\ttype\tsize");
@@ -48,17 +41,18 @@ mod async_example {
                     for (feature_index, (name, feature)) in example.into_iter().enumerate() {
                         print!("{}\t{}\t{}\t", example_index, feature_index, name);
 
-                        match feature {
-                            Feature::BytesList(list) => {
+                        use FeatureKind as F;
+                        match feature.into_kinds() {
+                            Some(F::Bytes(list)) => {
                                 println!("bytes\t{}", list.len());
                             }
-                            Feature::FloatList(list) => {
+                            Some(F::F32(list)) => {
                                 println!("float\t{}", list.len());
                             }
-                            Feature::Int64List(list) => {
+                            Some(F::I64(list)) => {
                                 println!("int64\t{}", list.len());
                             }
-                            Feature::None => {
+                            None => {
                                 println!("none");
                             }
                         }
